package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Authzr 获取 staffio Authorizer 单例
Register 线程安全,供各业务包 init() 调用
Routers 统一挂载,r 传入具体的路由器实例
type Strapper interface {
Strap(r any)
}
Strapper 接收 any,与具体框架解耦
StrapFunc 泛型辅助:让业务包写有类型的函数,内部自动处理断言
类型断言发生在已经依赖框架的业务包里
Source Files
¶
Click to show internal directories.
Click to hide internal directories.